# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['et_micc']

package_data = \
{'': ['*'],
 'et_micc': ['templates/app-simple/{{cookiecutter.project_name}}/tests/test_{{cookiecutter.cli_app_name}}.{{cookiecutter.py}}',
             'templates/app-simple/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/*',
             'templates/app-sub-commands/{{cookiecutter.project_name}}/tests/test_{{cookiecutter.cli_app_name}}.{{cookiecutter.py}}',
             'templates/app-sub-commands/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/*',
             'templates/module-cpp/{{cookiecutter.project_name}}/tests/test_cpp_{{cookiecutter.module_name}}.{{cookiecutter.py}}',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/CMakeLists.txt',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/CMakeLists.txt',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/CMakeLists.txt',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.cpp',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.cpp',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.cpp',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.rst',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.rst',
             'templates/module-cpp/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/cpp_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.rst',
             'templates/module-f2py/{{cookiecutter.project_name}}/tests/test_f2py_{{cookiecutter.module_name}}.{{cookiecutter.py}}',
             'templates/module-f2py/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/f2py_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.f90',
             'templates/module-f2py/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/f2py_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.f90',
             'templates/module-f2py/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/f2py_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.rst',
             'templates/module-f2py/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/f2py_{{cookiecutter.module_name}}/{{cookiecutter.module_name}}.rst',
             'templates/module-py/{{cookiecutter.project_name}}/tests/test_{{cookiecutter.module_name}}.{{cookiecutter.py}}',
             'templates/module-py/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/{{cookiecutter.module_name}}.{{cookiecutter.py}}',
             'templates/package-base/hooks/*',
             'templates/package-base/{{cookiecutter.project_name}}/.gitignore',
             'templates/package-base/{{cookiecutter.project_name}}/.gitignore',
             'templates/package-base/{{cookiecutter.project_name}}/.gitignore',
             'templates/package-base/{{cookiecutter.project_name}}/.gitignore',
             'templates/package-base/{{cookiecutter.project_name}}/LICENSE',
             'templates/package-base/{{cookiecutter.project_name}}/LICENSE',
             'templates/package-base/{{cookiecutter.project_name}}/LICENSE',
             'templates/package-base/{{cookiecutter.project_name}}/LICENSE',
             'templates/package-base/{{cookiecutter.project_name}}/Makefile',
             'templates/package-base/{{cookiecutter.project_name}}/Makefile',
             'templates/package-base/{{cookiecutter.project_name}}/Makefile',
             'templates/package-base/{{cookiecutter.project_name}}/Makefile',
             'templates/package-base/{{cookiecutter.project_name}}/pyproject.toml',
             'templates/package-base/{{cookiecutter.project_name}}/pyproject.toml',
             'templates/package-base/{{cookiecutter.project_name}}/pyproject.toml',
             'templates/package-base/{{cookiecutter.project_name}}/pyproject.toml',
             'templates/package-base/{{cookiecutter.project_name}}/tests/__init__.{{cookiecutter.py}}',
             'templates/package-base/{{cookiecutter.project_name}}/tests/__init__.{{cookiecutter.py}}',
             'templates/package-base/{{cookiecutter.project_name}}/tests/test_{{cookiecutter.package_name}}.{{cookiecutter.py}}',
             'templates/package-base/{{cookiecutter.project_name}}/tests/test_{{cookiecutter.package_name}}.{{cookiecutter.py}}',
             'templates/package-general-docs/hooks/*',
             'templates/package-general-docs/{{cookiecutter.project_name}}/APPS.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/APPS.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/APPS.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/AUTHORS.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/AUTHORS.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/AUTHORS.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/HISTORY.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/HISTORY.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/HISTORY.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/apps.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/apps.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/apps.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/apps.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/apps.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/authors.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/authors.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/authors.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/authors.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/authors.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/history.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/history.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/history.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/history.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/history.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/index.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/index.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/index.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/index.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/index.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/installation.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/installation.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/installation.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/installation.rst',
             'templates/package-general-docs/{{cookiecutter.project_name}}/docs/installation.rst',
             'templates/package-general/hooks/*',
             'templates/package-general/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}/*',
             'templates/package-simple-docs/hooks/*',
             'templates/package-simple-docs/{{cookiecutter.project_name}}/API.rst',
             'templates/package-simple-docs/{{cookiecutter.project_name}}/API.rst',
             'templates/package-simple-docs/{{cookiecutter.project_name}}/README.rst',
             'templates/package-simple-docs/{{cookiecutter.project_name}}/README.rst',
             'templates/package-simple-docs/{{cookiecutter.project_name}}/docs/*',
             'templates/package-simple/hooks/*',
             'templates/package-simple/{{cookiecutter.project_name}}/{{cookiecutter.package_name}}.{{cookiecutter.py}}']}

install_requires = \
['click>=7.0,<8.0',
 'cookiecutter>=1.6.0,<2.0.0',
 'semantic_version>=2.8.3,<3.0.0',
 'sphinx-click>=2.3.0,<3.0.0',
 'sphinx-rtd-theme>=0.4.3,<0.5.0',
 'tomlkit>=0.5.8,<0.6.0',
 'walkdir>=0.4.1,<0.5.0']

entry_points = \
{'console_scripts': ['micc = et_micc:cli_micc.main']}

setup_kwargs = {
    'name': 'et-micc',
    'version': '0.9.35',
    'description': 'A practical Python project skeleton generator.',
    'long_description': '****\nMicc\n****\n\nThis is work in progress!\n\n.. image:: https://img.shields.io/pypi/v/micc.svg\n        :target: https://pypi.python.org/pypi/micc\n\n.. image:: https://img.shields.io/travis/etijskens/micc.svg\n        :target: https://travis-ci.org/etijskens/micc\n\n.. image:: https://readthedocs.org/projects/micc/badge/?version=latest\n        :target: https://micc.readthedocs.io/en/latest/?badge=latest\n        :alt: Documentation Status\n\n\n*Micc* is a Python project manager: it can\n\n* create new projects\n* add python modules and applications\n* add and build binary extension modules written in C++ and Fortran.\n* build documentation (using `sphinx <http://www.sphinx-doc.org/>`_)\n* do version management and control (using `git <https://www.git-scm.com/>`_)\n* test your code (using `pytest <https://www.git-scm.com/>`_)\n\n\nTODO \n\n* facilitates publishing, e.g. `readthedocs <https://readthedocs.org>`_, `PyPI <https://pypi.org>`_  \n* facilitates CI\n\n.. _Cookiecutter: https://github.com/audreyr/cookiecutter\n',
    'author': 'Engelbert Tijskens',
    'author_email': 'engelbert.tijskens@uantwerpen.be',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/etijskens/et-micc',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)
